%define nginx_user      nginx
%define nginx_group     %{nginx_user}
%define nginx_home      %{_localstatedir}/lib/nginx
%define nginx_home_tmp  %{nginx_home}/tmp
%define nginx_logdir    %{_localstatedir}/log/nginx
%define nginx_confdir   %{_sysconfdir}/nginx
%define nginx_datadir   %{_datadir}/nginx
%define nginx_webroot   %{nginx_datadir}/html
%define nginx_moduledir %{nginx_datadir}/modules

Name:           nginx
Version:        1.9.12
Release:        1%{?dist}
Summary:        Robust, small and high performance http and reverse proxy server
Group:          System Environment/Daemons   

# BSD License (two clause)
# http://www.freebsd.org/copyright/freebsd-license.html
License:        BSD
URL:            http://nginx.net/ 
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

Source0:        http://sysoev.ru/nginx/nginx-%{version}.tar.gz
Source1:        %{name}.init
Source2:        %{name}.logrotate
Source3:        virtual.conf
Source4:        ssl.conf
Source5:        nginx-upstream-fair.tgz
Source6:        upstream-fair.conf
Source7:        %{name}.sysconfig
Source8:        nginx-push-stream-module-0.5.1.tar.gz
Source9:        http-push-stream.conf
Source10:       nginx-sticky-module-ng-1.2.5.tar.gz
Source11:       sticky-module.conf
Source12:       naxsi-core-0.53.2.tgz
Source13:       %{name}.service
Source14:       ngx_devel_kit-0.3.0.tar.gz
Source15:       devel-kit.conf
Source16:       form-input-nginx-module-0.12.tar.gz
Source17:       form-input.conf
Source100:      index.html
Source101:      nginx-logo.png
Source102:      50x.html
Source103:      404.html

BuildRequires:  pcre-devel,zlib-devel,openssl-devel,perl-devel,perl(ExtUtils::Embed),libxslt-devel,gd-devel,gcc,GeoIP-devel
# gperftools exist only on selected arches
%ifarch %{ix86} x86_64 ppc ppc64 %{arm}
BuildRequires:  gperftools-devel
%endif

Requires:       pcre,zlib,openssl,libxslt,gd,GeoIP
Requires:       perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

Provides:       webserver

%if 0%{?rhel} >= 7
BuildRequires:     systemd
Requires(post):    systemd
Requires(preun):   systemd
Requires(postun):  systemd
%else
Requires(post):    chkconfig
Requires(preun):   chkconfig, initscripts
Requires(postun):  initscripts
%endif

# removes -Werror in upstream build scripts.  -Werror conflicts with
# -D_FORTIFY_SOURCE=2 causing warnings to turn into errors.
Patch0:     nginx-auto-cc-gcc.patch

# configuration patch to match all the Fedora paths for logs, pid files
# etc.
Patch1:     nginx-conf.patch

%package nginx-devel-kit
Requires:       nginx >= 1.9.11
Summary:        NGiNX developers generic tools.

%package nginx-form-input
Requires:       nginx >= 1.9.11, nginx-devel-kit
Summary:        NGiNX module to read HTTP POST and PUT variables.


%description
Nginx [engine x] is an HTTP(S) server, HTTP(S) reverse proxy and IMAP/POP3
proxy server written by Igor Sysoev.

Third party modules supported (built-in):
- nginx-upstream-fair
- nginx-push-stream-module
- nginx-sticky-module-ng
- naxsi

%description nginx-devel-kit
NGiNX Development Kit is an Nginx module that adds additional generic tools that
module developers can use in their own modules.

%description nginx-form-input
NGiNX form imput is a module that reads HTTP POST and PUT request body encoded
in "application/x-www-form-urlencoded", and parse the arguments in request body
into nginx variables.


%prep
%setup -q

%patch0 -p0
%patch1 -p0
%{__tar} zxvf %{SOURCE5}
%{__tar} zxvf %{SOURCE8}
%{__tar} zxvf %{SOURCE10}
mv nginx-goodies-nginx-sticky-module-ng-bd312d586752 nginx-sticky-module-ng-1.2.5
%{__tar} zxvf %{SOURCE12}
%{__tar} zxvf %{SOURCE14}
%{__tar} zxvf %{SOURCE16}


%build
# nginx does not utilize a standard configure script.  It has its own
# and the standard configure options cause the nginx configure script
# to error out.  This is is also the reason for the DESTDIR environment
# variable.  The configure script(s) have been patched (Patch1 and
# Patch2) in order to support installing into a build environment.
export DESTDIR=%{buildroot}
./configure \
    --user=%{nginx_user} \
    --group=%{nginx_group} \
    --prefix=%{nginx_datadir} \
    --sbin-path=%{_sbindir}/%{name} \
    --conf-path=%{nginx_confdir}/%{name}.conf \
    --error-log-path=%{nginx_logdir}/error.log \
    --http-log-path=%{nginx_logdir}/access.log \
    --http-client-body-temp-path=%{nginx_home_tmp}/client_body \
    --http-proxy-temp-path=%{nginx_home_tmp}/proxy \
    --http-fastcgi-temp-path=%{nginx_home_tmp}/fastcgi \
    --http-uwsgi-temp-path=%{nginx_home_tmp}/uwsgi \
    --http-scgi-temp-path=%{nginx_home_tmp}/scgi \
%if 0%{?rhel} >= 7
    --pid-path=/run/nginx.pid \
    --lock-path=/run/lock/subsys/nginx \
%else
    --pid-path=%{_localstatedir}/run/%{name}.pid \
    --lock-path=%{_localstatedir}/lock/subsys/%{name} \
%endif
    --with-ipv6 \
    --with-http_ssl_module \
    --with-http_v2_module \
    --with-http_realip_module \
    --with-http_addition_module \
    --with-http_xslt_module \
    --with-http_image_filter_module \
    --with-http_geoip_module \
    --with-http_sub_module \
    --with-http_dav_module \
    --with-http_flv_module \
    --with-http_mp4_module \
    --with-http_gunzip_module \
    --with-http_gzip_static_module \
    --with-http_auth_request_module \
    --with-http_random_index_module \
    --with-http_secure_link_module \
    --with-http_degradation_module \
    --with-http_stub_status_module \
    --with-http_perl_module \
    --with-mail \
    --with-mail_ssl_module \
    --with-debug \
%ifnarch aarch64
    --with-file-aio \
%endif
%ifarch %{ix86} x86_64 ppc ppc64 %{arm}
    --with-google_perftools_module \
%endif
    --with-cc-opt="%{optflags} $(pcre-config --cflags)" \
    --with-ld-opt="$RPM_LD_FLAGS -Wl,-E" \
    --add-module=nginx-upstream-fair \
    --add-module=nginx-push-stream-module-0.5.1 \
    --add-module=nginx-sticky-module-ng-1.2.5 \
    --add-module=naxsi-core-0.53.2/naxsi_src \
    --add-dynamic-module=ngx_devel_kit-0.3.0 \
    --add-dynamic-module=form-input-nginx-module-0.12
make %{?_smp_mflags} 

# rename the readme for nginx-upstream-fair so it doesn't conflict with the main
# readme
mv nginx-upstream-fair/README nginx-upstream-fair/README.nginx-upstream-fair

# rename the nginx-http-push module documents so it doesn't conflict with the main
# documents
mv nginx-push-stream-module-0.5.1/AUTHORS nginx-push-stream-module-0.5.1/AUTHORS.nginx-http-push-stream
mv nginx-push-stream-module-0.5.1/CHANGELOG.textile nginx-push-stream-module-0.5.1/CHANGELOG.nginx-http-push-stream
mv nginx-push-stream-module-0.5.1/COPYING nginx-push-stream-module-0.5.1/COPYING.nginx-http-push-stream
mv nginx-push-stream-module-0.5.1/LICENSE nginx-push-stream-module-0.5.1/LICENSE.nginx-http-push-stream
mv nginx-push-stream-module-0.5.1/README.textile nginx-push-stream-module-0.5.1/README.nginx-http-push-stream

# rename the nginx-sticky-module module documents so it doesn't conflict with the
# main documents
mv nginx-sticky-module-ng-1.2.5/LICENSE nginx-sticky-module-ng-1.2.5/LICENCE.nginx-sticky-module
mv nginx-sticky-module-ng-1.2.5/README.md nginx-sticky-module-ng-1.2.5/README.nginx-sticky-module
mv nginx-sticky-module-ng-1.2.5/Changelog.txt nginx-sticky-module-ng-1.2.5/Changelog.txt.nginx-sticky-module
mv nginx-sticky-module-ng-1.2.5/docs/sticky.pdf nginx-sticky-module-ng-1.2.5/docs/nginx-sticky-module.pdf
mv nginx-sticky-module-ng-1.2.5/docs/sticky.vsd nginx-sticky-module-ng-1.2.5/docs/nginx-sticky-module.vsd


%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} INSTALLDIRS=vendor

find %{buildroot} -type f -name .packlist -exec rm -f {} \;
find %{buildroot} -type f -name perllocal.pod -exec rm -f {} \;
find %{buildroot} -type f -empty -exec rm -f {} \;
find %{buildroot} -type f -exec chmod 0644 {} \;
find %{buildroot} -type f -name '*.so' -exec chmod 0755 {} \;
chmod 0755 %{buildroot}%{_sbindir}/nginx
%if 0%{?rhel} >= 7
    %{__install} -p -D -m 0644 %{SOURCE13} %{buildroot}%{_unitdir}/%{name}.service
%else
    %{__install} -p -D -m 0755 %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
    %{__install} -p -D -m 0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%endif
%{__install} -p -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_confdir}/conf.d
%{__install} -p -m 0644 %{SOURCE3} %{SOURCE4} %{SOURCE6} %{SOURCE9} %{SOURCE11} %{SOURCE15} %{SOURCE17} %{buildroot}%{nginx_confdir}/conf.d
%{__install} -p -d -m 0755 %{buildroot}%{nginx_home}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_home_tmp}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_logdir}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_webroot}
%{__install} -p -m 0644 %{SOURCE100} %{SOURCE101} %{SOURCE102} %{SOURCE103} %{buildroot}%{nginx_webroot}
%{__install} -p -m 0644 naxsi-core-0.53.2/naxsi_config/naxsi_core.rules %{buildroot}%{nginx_confdir}/conf.d/naxsi_core.rules

%{__install} -p -D -m 0644 %{_builddir}/nginx-%{version}/man/nginx.8 %{buildroot}%{_mandir}/man8/nginx.8

for i in ftdetect indent syntax; do
    %{__install} -p -D -m644 contrib/vim/${i}/%{name}.vim %{buildroot}%{_datadir}/vim/vimfiles/${i}/%{name}.vim
done

# convert to UTF-8 all files that give warnings.
for textfile in CHANGES
do
    mv $textfile $textfile.old
    iconv --from-code ISO8859-1 --to-code UTF-8 --output $textfile $textfile.old
    rm -f $textfile.old
done

# remove fastcgi.conf (duplicated with fastcgi_params):
rm %{buildroot}%{nginx_confdir}/fastcgi.conf{,.default}


%clean
rm -rf %{buildroot}


%pre
%{_sbindir}/useradd -c "Nginx web server" -s /bin/false -r -d %{nginx_home} %{nginx_user} 2>/dev/null || :


%post
%if 0%{?rhel} >= 7
%systemd_post %{name}.service
%else
if [ $1 -eq 1 ]; then
    /sbin/chkconfig --add %{name}
fi
%endif


%preun
%if 0%{?rhel} >= 7
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
    /sbin/service %{name} stop >/dev/null 2>&1
    /sbin/chkconfig --del %{name}
fi
%endif


%postun
%if 0%{?rhel} >= 7
%systemd_postun %{name}.service
%else
if [ $1 -ge 1 ]; then
    /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif


%files nginx-devel-kit
%defattr(-,root,root,-)
%doc ngx_devel_kit-0.3.0/docs/core ngx_devel_kit-0.3.0/docs/modules ngx_devel_kit-0.3.0/docs/patches ngx_devel_kit-0.3.0/docs/upstream ngx_devel_kit-0.3.0/examples ngx_devel_kit-0.3.0/notes/CHANGES ngx_devel_kit-0.3.0/notes/LICENSE ngx_devel_kit-0.3.0/README_AUTO_LIB ngx_devel_kit-0.3.0/README.md ngx_devel_kit-0.3.0/TODO
%config %{nginx_confdir}/conf.d/devel-kit.conf
%{nginx_moduledir}/ndk_http_module.so

%files nginx-form-input
%defattr(-,root,root,-)
%doc form-input-nginx-module-0.12/README.md
%config %{nginx_confdir}/conf.d/form-input.conf
%{nginx_moduledir}/ngx_http_form_input_module.so

%files
%defattr(-,root,root,-)
%doc LICENSE CHANGES README nginx-upstream-fair/README.nginx-upstream-fair nginx-push-stream-module-0.5.1/AUTHORS.nginx-http-push-stream nginx-push-stream-module-0.5.1/CHANGELOG.nginx-http-push-stream nginx-push-stream-module-0.5.1/COPYING.nginx-http-push-stream nginx-push-stream-module-0.5.1/LICENSE.nginx-http-push-stream nginx-push-stream-module-0.5.1/README.nginx-http-push-stream nginx-sticky-module-ng-1.2.5/LICENCE.nginx-sticky-module nginx-sticky-module-ng-1.2.5/README.nginx-sticky-module nginx-sticky-module-ng-1.2.5/Changelog.txt.nginx-sticky-module nginx-sticky-module-ng-1.2.5/docs/nginx-sticky-module.pdf nginx-sticky-module-ng-1.2.5/docs/nginx-sticky-module.vsd
%dir %{nginx_datadir}
%{nginx_datadir}/html
%dir %{nginx_moduledir}
%{_sbindir}/%{name}
%{_datadir}/vim/vimfiles/ftdetect/nginx.vim
%{_datadir}/vim/vimfiles/syntax/nginx.vim
%{_datadir}/vim/vimfiles/indent/nginx.vim
%{_mandir}/man3/%{name}.3pm.gz
%{_mandir}/man8/%{name}.8*
%if 0%{?rhel} >= 7
%{_unitdir}/%{name}.service
%else
%{_initrddir}/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%endif
%dir %{nginx_confdir}
%dir %{nginx_confdir}/conf.d
%config(noreplace) %{nginx_confdir}/conf.d/http-push-stream.conf
%config(noreplace) %{nginx_confdir}/conf.d/naxsi_core.rules
%config(noreplace) %{nginx_confdir}/conf.d/ssl.conf
%config(noreplace) %{nginx_confdir}/conf.d/sticky-module.conf
%config(noreplace) %{nginx_confdir}/conf.d/upstream-fair.conf
%config(noreplace) %{nginx_confdir}/conf.d/virtual.conf
%config(noreplace) %{nginx_confdir}/win-utf
%config(noreplace) %{nginx_confdir}/%{name}.conf.default
%config(noreplace) %{nginx_confdir}/mime.types.default
%config(noreplace) %{nginx_confdir}/fastcgi_params
%config(noreplace) %{nginx_confdir}/fastcgi_params.default
%config(noreplace) %{nginx_confdir}/koi-win
%config(noreplace) %{nginx_confdir}/koi-utf
%config(noreplace) %{nginx_confdir}/%{name}.conf
%config(noreplace) %{nginx_confdir}/mime.types
%config(noreplace) %{nginx_confdir}/uwsgi_params
%config(noreplace) %{nginx_confdir}/uwsgi_params.default
%config(noreplace) %{nginx_confdir}/scgi_params
%config(noreplace) %{nginx_confdir}/scgi_params.default
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %{perl_vendorarch}/auto/%{name}
%{perl_vendorarch}/%{name}.pm
%{perl_vendorarch}/auto/%{name}/%{name}.so
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home_tmp}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_logdir}


%changelog
* Tue Jul  5 2016 Azevedo <azevedo@voipdomain.io> - 1.9.12-1
- update to 1.9.12 (mainline version)

* Tue Jul  5 2016 Azevedo <azevedo@voipdomain.io> - 1.9.11-1
- update to 1.9.11 (mainline version)
- added dynamic modules support
- added module nginx-devel-kit (modular supported)
- added module nginx-form-input (modular supported)

* Mon Feb 15 2016 Azevedo <azevedo@voipdomain.io> - 1.9.10-1
- update to 1.9.10 (mainline version)

* Fri Dec 11 2015 Azevedo <azevedo@voipdomain.io> - 1.9.9-1
- update to 1.9.9 (mainline version)

* Fri Dec 11 2015 Azevedo <azevedo@voipdomain.io> - 1.9.8-1
- update to 1.9.8 (mainline version)

* Fri Dec 11 2015 Azevedo <azevedo@voipdomain.io> - 1.9.7-1
- update to 1.9.7 (mainline version)

* Fri Dec 11 2015 Azevedo <azevedo@voipdomain.io> - 1.9.6-1
- update to 1.9.6 (mainline version)

* Tue Sep 22 2015 Azevedo <azevedo@voipdomain.io> - 1.9.5-1
- update to 1.9.5 (mainline version)
- removed obsolete spdy module
- added experimental http2 module

* Tue Sep 22 2015 Azevedo <azevedo@voipdomain.io> - 1.9.4-1
- update to 1.9.4 (mainline version)

* Tue Sep 22 2015 Azevedo <azevedo@voipdomain.io> - 1.9.3-1
- update to 1.9.3 (mainline version)

* Tue Sep 22 2015 Azevedo <azevedo@voipdomain.io> - 1.9.2-1
- update to 1.9.2 (mainline version)

* Tue Sep 22 2015 Azevedo <azevedo@voipdomain.io> - 1.9.1-1
- update to 1.9.1 (mainline version)

* Tue Sep 22 2015 Azevedo <azevedo@voipdomain.io> - 1.9.0-1
- update to 1.9.0 (mainline version)

* Thu May 21 2015 Azevedo <azevedo@voipdomain.io> - 1.8.0-3
- added support to systemd (RHEL/CentOS >= 7)

* Wed May  6 2015 Azevedo <azevedo@voipdomain.io> - 1.8.0-2
- updated nginx-push-stream-module to version 0.5.1
- removed obsolete nginx-sticky-module
- added nginx-sticky-module-ng version 1.2.5

* Wed Apr 22 2015 Azevedo <azevedo@voipdomain.io> - 1.8.0-1
- update to 1.8.0

* Sat Apr 18 2015 Azevedo <azevedo@voipdomain.io> - 1.6.3-1
- update to 1.6.3

* Sat Oct 11 2014 Azevedo <azevedo@voipdomain.io> - 1.6.2-1
- update to 1.6.2

* Sat Oct 11 2014 Azevedo <azevedo@voipdomain.io> - 1.6.1-1
- update to 1.6.1

* Tue May  6 2014 Azevedo <azevedo@voipdomain.io> - 1.6.0-1
- update to 1.6.0
- added linking parameters to fix CentOS/RHEL 7 linking bug

* Tue Mar 18 2014 Azevedo <azevedo@voipdomain.io> - 1.4.7-1
- update to 1.4.7

* Tue Mar 18 2014 Azevedo <azevedo@voipdomain.io> - 1.4.6-1
- update to 1.4.6

* Thu Mar 13 2014 Ernani Azevedo <azevedo@voipdomain.io> - 1.4.5-1
- update to 1.4.5

* Thu Mar 13 2014 Ernani Azevedo <azevedo@voipdomain.io> - 1.4.4-1
- update to 1.4.4

* Tue Oct 29 2013 Ernani Azevedo <azevedo@voipdomain.io> - 1.4.3-1
- update to 1.4.3

* Fri Aug 30 2013 Ernani Azevedo <azevedo@voipdomain.io> - 1.4.2-1
- update to 1.4.2

* Wed May  8 2013 Ernani Azevedo <azevedo@voipdomain.io> - 1.4.1-1
- update to 1.4.1

* Thu Apr 25 2013 Ernani Azevedo <azevedo@voipdomain.io> - 1.4.0-1
- update to 1.4.0

* Mon Apr 22 2013 Ernani Azevedo <azevedo@voipdomain.io> - 1.2.8-1
- update to 1.2.8
- removed extra module httpd-push-server (obsolete due to nginx-push-stream-module)
- added extra module nginx-push-stream-module
- added extra module naxsi module

* Tue Feb 19 2013 Ernani Azevedo <azevedo@voipdomain.io> - 1.2.7-1
- update to 1.2.7

* Tue Feb 19 2013 Ernani Azevedo <azevedo@voipdomain.io> - 1.2.6-1
- update to 1.2.6

* Tue Feb 19 2013 Ernani Azevedo <azevedo@voipdomain.io> - 1.2.5-1
- update to 1.2.5

* Mon Oct  1 2012 Ernani Azevedo <azevedo@voipdomain.io> - 1.2.4-1
- update to 1.2.4

* Mon Oct  1 2012 Ernani Azevedo <azevedo@voipdomain.io> - 1.2.3-1
- update to 1.2.3

* Mon Oct  1 2012 Ernani Azevedo <azevedo@voipdomain.io> - 1.2.2-1
- update to 1.2.2

* Mon Jun 11 2012 Ernani Azevedo <azevedo@voipdomain.io> - 1.2.1-1
- update to 1.2.1
- added extra module sticky-module
- added extra module httpd-push-server

* Mon May 14 2012 Ernani Azevedo <azevedo@voipdomain.io> - 1.2.0-1
- update to 1.2.0

* Mon May 14 2012 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.15-1
- update to 1.0.15

* Mon Apr 09 2012 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.14-1
- update to 1.0.14

* Mon Apr 09 2012 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.13-1
- update to 1.0.13

* Mon Apr 09 2012 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.12-1
- update to 1.0.12

* Mon Apr 09 2012 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.11-1
- update to 1.0.11

* Mon Nov 07 2011 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.10-1
- update to 1.0.10

* Mon Nov 07 2011 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.9-1
- update to 1.0.9

* Mon Nov 07 2011 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.8-1
- update to 1.0.8
- added support to MP4 HTTP module

* Mon Nov 07 2011 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.7-1
- update to 1.0.7

* Thu Sep 29 2011 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.6-1
- update to 1.0.6

* Thu Sep 29 2011 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.5-1
- update to 1.0.5

* Tue Jun 28 2011 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.4-1
- update to 1.0.4

* Tue Jun 28 2011 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.3-1
- update to 1.0.3

* Tue Jun 28 2011 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.2-1
- update to 1.0.2

* Tue Jun 28 2011 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.1-1
- update to 1.0.1

* Tue Jun 28 2011 Ernani Azevedo <azevedo@voipdomain.io> - 1.0.0-1
- update to 1.0.0

* Tue Dec 14 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.54-1
- update to 0.8.54

* Tue Dec 14 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.53-1
- update to 0.8.53

* Wed Oct 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.52-1
- update to 0.8.52
- removed EPEL references

* Wed Oct 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.51-1
- update to 0.8.51

* Wed Oct 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.50-1
- update to 0.8.50

* Wed Oct 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.49-1
- update to 0.8.49

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.48-1
- update to 0.8.48

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.47-1
- update to 0.8.47

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.46-1
- update to 0.8.46

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.45-1
- update to 0.8.45

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.44-1
- update to 0.8.44

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.43-1
- update to 0.8.43

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.42-1
- update to 0.8.42

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.41-1
- update to 0.8.41

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.40-1
- update to 0.8.40

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.39-1
- update to 0.8.39

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.38-1
- update to 0.8.38

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.37-1
- update to 0.8.37

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.36-1
- update to 0.8.36

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.35-1
- update to 0.8.35

* Fri Aug 06 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.34-1
- update to 0.8.34

* Tue Feb 09 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.33-1
- update to 0.8.33

* Tue Feb 09 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.32-1
- update to 0.8.32

* Tue Feb 09 2010 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.31-1
- update to 0.8.31

* Thu Dec 17 2009 Ernani Azevedo <azevedo@voipdomain.io> - 0.8.30-1
- update to 0.8.30

* Fri Dec 04 2009 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.6.39-2
- fixes CVE-2009-3555

* Mon Sep 14 2009 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.6.39-1
- update to 0.6.39
- fixes CVE-2009-2629

* Sun Aug 02 2009 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.6.38-1
- update to 0.6.38

* Sat Apr 11 2009 Jeremy Hinegardner <jeremy@hinegardner.org> 0.6.36-1
-  update to 0.6.36

* Thu Feb 19 2009 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.6.35-2
- rebuild

* Thu Feb 19 2009 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.6.35-1
- update to 0.6.35

* Tue Dec 30 2008 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.6.34-1
- update to 0.6.34
- Fix inclusion of /usr/share/nginx tree => no unowned directories [mschwendt]

* Sun Nov 23 2008 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.6.33-1
- update to 0.6.33

* Sun Jul 27 2008 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.6.32-1
- update to 0.6.32
- nginx now supports DESTDIR so removed the patches that enabled it

* Mon May 26 2008 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.6.31-3
- update init script
- remove 'default' listen parameter

* Tue May 13 2008 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.6.31-2
- added missing Source files

* Mon May 12 2008 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.6.31-1
- update to new upstream stable branch 0.6
- added 3rd party module nginx-upstream-fair
- add /etc/nginx/conf.d support [#443280]
- use /etc/sysconfig/nginx to determine nginx.conf [#442708]
- added default webpages
- add Requires for versioned perl (libperl.so) (via Tom "spot" Callaway)
- drop silly file Requires (via Tom "spot" Callaway)

* Sat Jan 19 2008 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.35-1
- update to 0.5.35

* Sun Dec 16 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.34-1
- update to 0.5.34

* Mon Nov 12 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.33-2
- bump build number - source wasn't update

* Mon Nov 12 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.33-1
* update to 0.5.33

* Mon Sep 24 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.32-1
- updated to 0.5.32
- fixed rpmlint UTF-8 complaints.

* Sat Aug 18 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.31-3
- added --with-http_stub_status_module build option.
- added --with-http_sub_module build option.
- add in pcre-config --cflags

* Sat Aug 18 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.31-2
- remove BuildRequires: perl-devel

* Fri Aug 17 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.31-1
- Update to 0.5.31
- specify license is BSD

* Sat Aug 11 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.30-2
- Add BuildRequires: perl-devel - fixing rawhide build

* Mon Jul 30 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.30-1
- Update to 0.5.30

* Tue Jul 24 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.29-1
- Update to 0.5.29

* Wed Jul 18 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.28-1
- Update to 0.5.28

* Mon Jul 09 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.27-1
- Update to 0.5.27

* Mon Jun 18 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.26-1
- Update to 0.5.26

* Sat Apr 28 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.19-1
- Update to 0.5.19

* Mon Apr 02 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.17-1
- Update to 0.5.17

* Mon Mar 26 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.16-1
- Update to 0.5.16
- add ownership of /usr/share/nginx/html (#233950)

* Fri Mar 23 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.15-3
- fixed package review bugs (#235222) given by ruben@rubenkerkhof.com

* Thu Mar 22 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.15-2
- fixed package review bugs (#233522) given by kevin@tummy.com

* Thu Mar 22 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.15-1
- create patches to assist with building for Fedora
- initial packaging for Fedora
